==> myfaces-tobago-1.5.13-source-release.zip: tobago-1.5.13/tobago-core/src/main/java/org/apache/myfaces/tobago/model/AutoSuggestItems.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.myfaces.tobago.model;


import java.util.List;

public class AutoSuggestItems {

  private List<AutoSuggestItem> items;

  private String nextFocusId;

  private int maxSuggestedCount = 25;

  public List<AutoSuggestItem> getItems() {
    return items;
  }

  public void setItems(List<AutoSuggestItem> items) {
    this.items = items;
  }

  public String getNextFocusId() {
    return nextFocusId;
  }

  public void setNextFocusId(String nextFocusId) {
    this.nextFocusId = nextFocusId;
  }

  public int getMaxSuggestedCount() {
    return maxSuggestedCount;
  }

  public void setMaxSuggestedCount(int maxSuggestedCount) {
    this.maxSuggestedCount = maxSuggestedCount;
  }
}

==> myfaces-tobago-2.5.1-source-release.zip: tobago-2.5.1/tobago-core/src/main/java/org/apache/myfaces/tobago/model/AutoSuggestItems.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.myfaces.tobago.model;


import java.util.List;

public class AutoSuggestItems {

  private List<AutoSuggestItem> items;

  private String nextFocusId;

  private int maxSuggestedCount = 25;

  public List<AutoSuggestItem> getItems() {
    return items;
  }

  public void setItems(final List<AutoSuggestItem> items) {
    this.items = items;
  }

  public String getNextFocusId() {
    return nextFocusId;
  }

  public void setNextFocusId(final String nextFocusId) {
    this.nextFocusId = nextFocusId;
  }

  public int getMaxSuggestedCount() {
    return maxSuggestedCount;
  }

  public void setMaxSuggestedCount(final int maxSuggestedCount) {
    this.maxSuggestedCount = maxSuggestedCount;
  }
}
